@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dancer2::Plugin::JWT;
 # ABSTRACT: JSON Web Token made simple for Dancer2
-$Dancer2::Plugin::JWT::VERSION = '0.014';
+$Dancer2::Plugin::JWT::VERSION = '0.015';
 use Dancer2::Plugin;
 use Crypt::JWT qw(encode_jwt decode_jwt);
 use URI;
@@ -38,7 +38,7 @@ on_plugin_import {
     my $dsl = shift;
 
     my $config = plugin_setting;
-    die "JWT cannot be used without a secret!" unless exists $config->{secret};
+    die "JWT cannot be used without a secret!" unless (exists $config->{secret} && defined $config->{secret});
     # For RSA and ES algorithms - path to keyfile or JWK string, others algorithms - just secret string
     $secret = $config->{secret};
 
